@@ -40,4 +40,25 @@ class Account(object):
         """
         return request_get(request_tools.settle_account_detail_query, kwargs)
 
+    @classmethod
+    def query_balance(cls, **kwargs):
+        """
+        查询账户余额
+        """
+        return request_get(request_tools.settle_account_balance_query, kwargs)
+
+    @classmethod
+    def draw_cash(cls, **kwargs):
+        """
+        取现
+        """
+        return request_post(request_tools.settle_account_cash_draw, kwargs)
+
+    @classmethod
+    def query_draw_cash_status(cls, **kwargs):
+        """
+        取现状态查询
+        """
+        return request_get(request_tools.cash_draw_status, kwargs)
+
 
